#!/bin/bash
#
# Title: pk3 search
# Created By: Tyler "-z-" Mulligan of www.xonotic.org
#
# This plugin provides a way for you to search through pk3 files
# and files within the package.
#

# include the global variables
CD="$(cd "$(dirname $0)"; pwd | sed 's#/extra/plugins##')"
. $CD/xst.inc

# Search packs searches all packages in your xst directory
pk3_filename_search() {
	if [[ "$1" != "" ]]; then
		string=$1
	else
		echo "[YOU FAIL] How can I search packages for nothing?"; exit 0
	fi
	
	# Get the a list of all packages
	for package in $( find $CD -name "*.pk3" ); do
		echo "Searhing: " $package
		
		# List contents, grab the name of the bsp, remove the folder name, drop any bsp not in the maps folder
		found=`unzip -l $package | grep $string | awk '{ print $4 }'`
		# If the string is found
		if [[ "$found" != "" ]]; then
            for f in $found; do
    			echo "  -- found --> " $f | grep --color $string # attempt to highlight
            done
		fi
	done
	exit 0
}

pk3_mapinfo_search() {
	if [[ "$1" != "" ]]; then
		string=$1
	else
		echo "[YOU FAIL] How can I search packages for nothing?"; exit 0
	fi
	
	# Get the a list of all packages
    mkdir $CD/.tmp
	for package in $( find $CD -name "*.pk3" ); do
		echo -e "\nSearhing: " $package
		# List contents, grab the name of the bsp, remove the folder name, drop any bsp not in the maps folder
		found=$(unzip -l $package | egrep "*.mapinfo" | awk '{ print $4 }')
		# If the string is found
		if [[ "$found" == "" ]]; then
    		echo -e " ^^^  mapinfo not found ^^^"
        else
            filename=$(echo -e $found | awk -F/ '{ print $NF }') 
            unzip -j -qq -aC $package "$found" -d $CD/.tmp
            echo "found: $filename"
            grep --color $string $CD/.tmp/$filename
		fi
	done
    rm -r $CD/.tmp
    exit 0  
}

not_found() { exit 42; }

if [[ $1 == "--phs" ]]; then # Plugin Help System
    echo "    --pk3-filename-search | --pfs                        Searching through pk3 pacakges for a given string.
    --pk3-mapinfo-search | --pms                        Searching through mapinfos inside pk3 pacakges for a given string."
    exit 0;
fi

case $1 in
  --pk3-filename-search|--pfs) pk3_filename_search $2;;
  --pk3-mapinfo-search|--pms) pk3_mapinfo_search $2;;
  *) not_found;;
esac

