#!/bin/bash
# xst.inc.sh
# REQUIRED by both the core and plugin files
# Sets global variables and private functions
#

CD="$(cd "$( dirname "$0" )" && pwd | sed 's#/extra/plugins##')" # figure out what dir this script is running out of
if [[ ! -f $CD/xst.conf ]]; then echo "An xst.conf file is required to operate"; exit 0; fi
. $CD/xst.conf						  # load the xst.conf file

XD="$(cd "$CD" && cd "$XD" && pwd)"   # figure out what dir this xonotic is running out of
if [[ -d $XD ]]; then                 # make sure the xonotic dir exists and assume ./all is there
    XD=$(cd $XD && pwd) 	    	  # get the full path to xonotic ./all
else
    echo "!! Warning, Xonotic directory '$XD' does not yet exist.  Did you want to install it? (y/n)"
    read a
    if [[ "$a" == "y" ]]; then
        xonotic_install
    else
        echo "xst cannot operate without Xonotic, please install Xonotic or edit your configuration to point to your Xonotic directory"
        exit 0;
    fi
fi

# builds a global array of servers ${SA[@]}
__build_server_array() {
    for c in $(find $CD/servers -maxdepth 1 -type f -name "*.conf"); do
        SA[${#SA[*]}]=$(echo $c | sed "s#$CD/servers/##;s/\.conf$//")
    done
}

# builds a global array of servers with "autoload=1" ${ASA[@]}
__build_autoload_server_array() {
    for c in $(find $CD/servers -maxdepth 1 -type f -name "*.conf"); do
        if [[ $(($(grep "autoload=1" $c | wc -l))) > 0 ]]; then
            ASA[${#ASA[*]}]=$(echo $c | sed "s#$CD/servers/##;s/\.conf$//")
        fi
    done
}
